Attribute VB_Name = "RDesktop_bas"
Option Explicit

' You can send to the Windows shell one of the following messages:
' Message             Description
' --------------      --------------------------------------------------
' ABM_NEW             Register a new AppBar to the system
' ABM_REMOVE          Remove a previously created AppBar from the system
' ABM_QUERYPOS        Query the AppBar position
' ABM_SETPOS          Set the AppBar position
' ABM_GETSTATE        Get the edge the Appbar is docked to
' ABM_GETTASKBARPOS   Get the Explorer Taskbar position
' ABM_ACTIVATE        Activate the AppBar
' ABM_GETAUTOHIDEBAR  Query if AppBar has Auto-hide behavior
' ABM_SETAUTOHIDEBAR  Set the AppBar's Auto-hide behavior

' The ABM_message constants are defined in SHELLAPI.H as follows:
Private Const ABM_NEW = &H0
Private Const ABM_REMOVE = &H1
Private Const ABM_QUERYPOS = &H2
Private Const ABM_SETPOS = &H3
Private Const ABM_GETSTATE = &H4
Private Const ABM_GETTASKBARPOS = &H5
Private Const ABM_ACTIVATE = &H6
Private Const ABM_GETAUTOHIDEBAR = &H7
Private Const ABM_SETAUTOHIDEBAR = &H8
Private Const ABM_WINDOWPOSCHANGED = &H9

' An AppBar can be in one of 6 states shown in the table below:
' State          Description
' -----------    -----------------------------------------------------
' ABE_UNKNOWN    The Appbar is in an unknown state
'                (usually during construction/destruction)
' ABE_FLOAT      The AppBar is floating on the screen
' ABE_LEFT       The Appbar is docked on the left   edge of the screen
' ABE_TOP        The Appbar is docked on the top    edge of the screen
' ABE_RIGHT      The Appbar is docked on the right  edge of the screen
' ABE_BOTTOM     The Appbar is docked on the bottom edge of the screen

' The ABE_edge state constants are defined in SHELLAPI.H as follows:
Private Const ABE_LEFT = 0
Private Const ABE_TOP = 1
Private Const ABE_RIGHT = 2
Private Const ABE_BOTTOM = 3

' The ABE_UNKNOWN and ABE_FLOAT constants are defined here as follows:
Private Const ABE_UNKNOWN = 4
Private Const ABE_FLOAT = 5

' An AppBar can have several behavior flags as shown below:
' Flag                        Description
' --------------------------- -----------------------------------
' ABF_ALLOWLEFT               Allow dock on left   of screen
' ABF_ALLOWRIGHT              Allow dock on right  of screen
' ABF_ALLOWTOP                Allow dock on top    of screen
' ABF_ALLOWBOTTOM             Allow dock on bottom of screen
' ABF_ALLOWFLOAT              Allow float in the middle of screen

' The ABF_* constants are defined here as follows:
Private Const ABF_ALLOWLEFT = 1
Private Const ABF_ALLOWRIGHT = 2
Private Const ABF_ALLOWTOP = 4
Private Const ABF_ALLOWBOTTOM = 8
Private Const ABF_ALLOWFLOAT = 16

' The ABN_* constants are defined here as follows:
Private Const ABN_FULLSCREENAPP = &H2
Private Const ABN_POSCHANGED = &H1
Private Const ABN_WINDOWARRANGE = &H3

Private Const WM_USER = &H400 'user messages > H400
Private Const WM_APPBARNOTIFY = WM_USER + 100 'message kon s'en calis

' SHAppBarMessage
Private Declare Function SHAppBarMessage _
                Lib "shell32.dll" _
                (ByVal dwMessage As Long, pData As APPBARDATA) As Long

Private Type Rect
   Left As Long
   Top As Long
   Right As Long
   Bottom As Long
End Type

Private Type APPBARDATA
   cbSize As Long
   hwnd As Long
   uCallbackMessage As Long
   uEdge As Long
   rc As Rect
   lParam As Long
End Type

Public Sub RefreshDesktop(apphwnd As Long)
   Dim abd As APPBARDATA
   
   On Error Resume Next
   abd.hwnd = Main.hwnd
   abd.cbSize = Len(abd)
   abd.uCallbackMessage = WM_APPBARNOTIFY
   Call SHAppBarMessage(ABM_NEW, abd)
   abd.rc.Left = 0
   abd.rc.Top = 0
   abd.rc.Right = 0
   abd.rc.Bottom = 0
   Call SHAppBarMessage(ABM_SETPOS, abd)
   'Call SHAppBarMessage(ABM_ACTIVATE, abd)
   Call SHAppBarMessage(ABM_REMOVE, abd)
   On Error GoTo 0
End Sub

